﻿using System;
using System.Globalization;
using System.Windows.Data;
using System.Windows.Media;
using Infragistics.Controls.Charts;

namespace Infragistics.Extensions
{
    public class ValueToBrushConverter : IValueConverter
    {
        public ValueToBrushConverter()
        {
           
            BrushScale = new ValueBrushScale();
            BrushScale.MinimumValue = 0;
            BrushScale.MaximumValue = 1;
            BrushScale.Brushes = new BrushCollection()
                {
                    new SolidColorBrush(Colors.DodgerBlue),
                    new SolidColorBrush(Colors.Yellow),
                    new SolidColorBrush(Colors.Red),
                };


        }
        public ValueBrushScale BrushScale { get; set; }
        //protected BrushScale Scale { get; set; }
       
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            if (value == null)
                return new SolidColorBrush(Colors.Transparent);
            
            //if (!(value is double) || !(value is float))
            //    return new SolidColorBrush(Colors.Transparent);
            var actual  = System.Convert.ToDouble(value);
             
            //var actual = (double)value;

            var scale = new BrushScale();
            scale.MinimumValue = BrushScale.MinimumValue;
            scale.MaximumValue = BrushScale.MaximumValue;
            var brush = scale.GetBrushByValue(actual, BrushScale.Brushes);
           
            //var scaleValues = new DoubleObsCollection { BrushScale.MinimumValue, BrushScale.MaximumValue };
            //var brush = BrushScale.GetBrushByValue(actual, scaleValues);
           
            return brush ?? new SolidColorBrush(Colors.Transparent);
        }

        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public abstract class ValueScale
    {
        /// <summary>
        /// Sets or gets the Minimum value for this scale.
        /// </summary>
        public virtual double MinimumValue { get; set; }

        /// <summary>
        /// Sets or gets the Maximum value for this scale.
        /// </summary>
        public virtual double MaximumValue { get; set; }
        public virtual DoubleCollection ValueStops { get; set; }

        protected double GetUnscaledValue(double v)
        {
            return MathUtil.Clamp(MinimumValue + v * (MaximumValue - MinimumValue), MinimumValue, MaximumValue);
        }
        /// <summary>
        /// Gets a scaled value from the parameter value. 
        /// </summary>
        protected double GetScaledValue(double v)
        {
            if (double.IsNaN(v) || double.IsInfinity(v))
            {
                return v;
            }
            return MathUtil.Clamp((v - MinimumValue) / (MaximumValue - MinimumValue), 0.0, 1.0);
        }
        ///// <summary>
        ///// Gets a scaled brush from the parameter value.
        ///// </summary>
        //public abstract Brush GetBrush(double v, BrushCollection brushes);

    }
    public sealed class BrushScale : ValueScale
    {
        public BrushScale()
        {
            MinimumValue = 0;
            MaximumValue = 100;
        }

        public Brush GetBrushByValue(double v, BrushCollection brushes)
        {
       
            double index = GetScaledValue(v) * (brushes.Count - 1);
            return index > brushes.Count ?
                new SolidColorBrush(Colors.Red) :
                brushes[GetScaledValue(v) * (brushes.Count - 1)];
        }
    }
  

}