﻿using System;
using System.Collections.ObjectModel;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Windows.Threading;
 
namespace Infragistics.Extensions
{
    public class SampleScatterData3D : AnnimationModel
    {
        protected int PointCount = 500;
        
        public SampleScatterData3D()
        {
            Data = new ScatterData3D(PointCount, DataSeed);
            Timer.Interval = TimeSpan.FromMilliseconds(40);
        }

        public override void RefreshData()
        {
            DataSeed += 0.01;
            Data.Update(DataSeed);
        }
        
        private ScatterData3D _data;
        public ScatterData3D Data
        {
            get { return _data; }
            private set
            {
                _data = value;
                OnPropertyChanged("Data");
            }
        }
    }

    public class ScatterData3D : ObservableCollection<ScatterPoint3D> 
    {
        public ScatterData3D(int count, double seed)
        {
            for (int i = 0; i < count; ++i)
            {
                Add(new ScatterPoint3D(seed));
            }
        }
        public void Update(double seed)
        {
            seed += 0.01;
            foreach (var r in this)
            {
                r.Update(seed);
            }
               
            OnCollectionChanged(new NotifyCollectionChangedEventArgs(NotifyCollectionChangedAction.Reset));
        }

        private double _minZ;
        public double MinZ
        {
            get { return _minZ; }
            set { _minZ = value; OnPropertyChanged("MinZ"); }
        }
        private double _maxZ;
        public double MaxZ
        {
            get { return _maxZ; }
            set { _maxZ = value; OnPropertyChanged("MaxZ"); }
        }

        public new event PropertyChangedEventHandler PropertyChanged;
        public void OnPropertyChanged(string propertyName)
        {
            OnPropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        protected void OnPropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            PropertyChangedEventHandler handler = this.PropertyChanged;
            if (handler != null)
                handler(sender, e);
        }
    }
    public class ScatterPoint3D : ScatterPoint
    {
        protected static Random Random = new Random();

        public ScatterPoint3D(double seed)
        {
            _x = 100.0 * Random.NextDouble();
            _y = 100.0 * Random.NextDouble();
            _z = MathUtil.Noise(0.02 * X, 0.02 * Y, seed);
        }

        public void Update(double seed)
        {
            _z = MathUtil.Noise(0.02 * X, 0.02 * Y, seed);
            _value = _z;
        }
        
        private double _z;
        public double Z
        {
            get { return _z; }
            set { _z = value; OnPropertyChanged("Z"); }
        }
         
    }
  
}