﻿using System;
using System.Collections.Generic;
 
namespace Infragistics.Extensions
{
    public class ScatterGridData : AnnimationModel
    {
        protected int RowCount = 32;
        protected int ColumnsCount = 64;
        protected double DataSeed = 0.0;
      
        public ScatterGridData()
        {
            var rows = new List<Ticker>();

            for (int i = 0; i < RowCount; ++i)
            {
                rows.Add(new Ticker { Symbol = Symbols[i, 0], Name = Symbols[i, 1] });
            }

            var cols = new List<DateTime>();

            for (int i = 0; i < ColumnsCount; ++i)
            {
                cols.Add(DateTime.Today.AddDays(i - ColumnsCount));
            }

            Rows = rows;
            Columns = cols;
            RefreshData();
        }
        #region Properties
        private ScatterGridItem[,] _data;
        public ScatterGridItem[,] Data
        {
            get { return _data; }
            set
            {
                if (_data != value)
                {
                    _data = value;
                    OnPropertyChanged("Data");
                }
            }
        }
      
        private List<Ticker> _rows;
        public List<Ticker> Rows
        {
            get { return _rows; }
            set
            {
                if (_rows != value)
                {
                    _rows = value;
                    OnPropertyChanged("Rows");
                }
            }
        }
      
        private List<DateTime> _columns;
        public List<DateTime> Columns
        {
            get { return _columns; }
            set
            {
                if (_columns != value)
                {
                    _columns = value;
                    OnPropertyChanged("Cols");
                }
            }
        }
        #endregion

        public override sealed void RefreshData()
        {
            var data = new ScatterGridItem[RowCount, ColumnsCount];

            for (int row = 0; row < data.GetLength(0); ++row)
            {
                for (int col = 0; col < data.GetLength(1); ++col)
                {
                    double x = 5.0 * col / data.GetLength(1);
                    double y = 30.0 * row / data.GetLength(0);

                    data[row, col] = new ScatterGridItem()
                        {
                            Ticker = Rows[row],
                            Date = Columns[col],
                            Value = 100 * MathUtil.Noise(x, y, DataSeed)
                        };
                }
            }
            DataSeed += 0.1;
            Data = data;
        }

        protected readonly string[,] Symbols =
        {
            #region symbol/name pairs
            { "ATVI", "Activision Blizzard, Inc" },
            { "ADBE", "Adobe Systems Incorporated" },
            { "AKAM", "Akamai Technologies, Inc." },
            { "ALXN", "Alexion Pharmaceuticals, Inc." },
            { "ALTR", "Altera Corporation" },
            { "AMZN", "Amazon.com, Inc." },
            { "AMGN", "Amgen Inc." },
            { "APOL", "Apollo Group, Inc." },
            { "AAPL", "Apple Inc." },
            { "AMAT", "Applied Materials, Inc." },
            { "ADSK", "Autodesk, Inc." },
            { "ADP", "Automatic Data Processing, Inc." },
            { "BIDU", "Baidu, Inc." },
            { "BBBY", "Bed Bath & Beyond Inc." },
            { "BIIB", "Biogen Idec Inc" },
            { "BMC", " BMC Software, Inc." },
            { "BRCM", "Broadcom Corporation" },
            { "CHRW", "C.H. Robinson Worldwide, Inc." },
            { "CA", "CA Inc." },
            { "CELG", "Celgene Corporation" },
            { "CERN", "Cerner Corporation" },
            { "CHKP", "Check Point Software Technologies Ltd." },
            { "CSCO", "Cisco Systems, Inc." },
            { "CTXS", "Citrix Systems, Inc." },
            { "CTSH", "Cognizant Technology Solutions Corporation" },
            { "CMCSA", "Comcast Corporation" },
            { "COST", "Costco Wholesale Corporation" },
            { "CTRP", "Ctrip.com International, Ltd." },
            { "DELL", "Dell Inc." },
            { "XRAY", "DENTSPLY International Inc." },
            { "DTV", "DIRECTV" },
            { "DLTR", "Dollar Tree, Inc." },
            { "EBAY", "eBay Inc." },
            { "ERTS", "Electronic Arts Inc." },
            { "EXPE", "Expedia, Inc." },
            { "EXPD", "Expeditors International of Washington, Inc." },
            { "ESRX", "Express Scripts, Inc." },
            { "FFIV", "F5 Networks, Inc." },
            { "FAST", "Fastenal Company" },
            { "FSLR", "First Solar, Inc." },
            { "FISV", "Fiserv, Inc." },
            { "FLEX", "Flextronics International Ltd." },
            { "FLIR", "FLIR Systems, Inc." },
            { "GRMN", "Garmin Ltd." },
            { "GILD", "Gilead Sciences, Inc." },
            { "GOOG", "Google Inc." },
            { "GMCR", "Green Mountain Coffee Roasters, Inc." },
            { "HSIC", "Henry Schein, Inc." },
            { "ILMN", "Illumina, Inc." },
            { "INFY", "Infosys Limited" },
            { "INTC", "Intel Corporation" },
            { "INTU", "Intuit Inc." },
            { "ISRG", "Intuitive Surgical, Inc." },
            { "JOYG", "Joy Global Inc." },
            { "KLAC", "KLA-Tencor Corporation" },
            { "LRCX", "Lam Research Corporation" },
            { "LINTA", "Liberty Media Corporation" },
            { "LIFE", "Life Technologies Corporation" },
            { "LLTC", "Linear Technology Corporation" },
            { "MRVL", "Marvell Technology Group Ltd." },
            { "MAT", "Mattel, Inc." },
            { "MXIM", "Maxim Integrated Products, Inc." },
            { "MCHP", "Microchip Technology Incorporated" },
            { "MU", "Micron Technology, Inc." },
            { "MSFT", "Microsoft Corporation" },
            { "MYL", "Mylan Inc." },
            { "NTAP", "NetApp, Inc." },
            { "NFLX", "Netflix, Inc." },
            { "NWSA", "News Corporation" },
            { "NIHD", "NII Holdings, Inc." },
            { "NVDA", "NVIDIA Corporation" },
            { "ORLY", "O'Reilly Automotive, Inc." },
            { "ORCL", "Oracle Corporation" },
            { "PCAR", "PACCAR Inc." },
            { "PAYX", "Paychex, Inc." },
            { "PCLN", "priceline.com Incorporated" },
            { "QGEN", "Qiagen N.V." },
            { "QCOM", "QUALCOMM Incorporated" },
            { "RIMM", "Research in Motion Limited" },
            { "ROST", "Ross Stores, Inc." },
            { "SNDK", "SanDisk Corporation" },
            { "STX", "Seagate Technology." },
            { "SHLD", "Sears Holdings Corporation" },
            { "SIAL", "Sigma-Aldrich Corporation" },
            { "SIRI", "Sirius XM Radio Inc." },
            { "SPLS", "Staples, Inc." },
            { "SBUX", "Starbucks Corporation" },
            { "SRCL", "Stericycle, Inc." },
            { "SYMC", "Symantec Corporation" },
            { "TEVA", "Teva Pharmaceutical Industries Limited" },
            { "URBN", "Urban Outfitters, Inc." },
            { "VRSN", "VeriSign, Inc." },
            { "VRTX", "Vertex Pharmaceuticals Incorporated" },
            { "VMED", "Virgin Media Inc." },
            { "VOD", "Vodafone Group Plc" },
            { "WCRX", "Warner Chilcott plc" },
            { "WFM", "Whole Foods Market, Inc." },
            { "WYNN", "Wynn Resorts, Limited" },
            { "XLNX", "Xilinx, Inc." },
            { "YHOO", "Yahoo! Inc." }
            #endregion
        };
    }

    public class ScatterGridItem
    {
        public Ticker Ticker { get; set; }
        public DateTime Date { get; set; }
        public double Value { get; set; }
    }
    public class Ticker
    {
        public string Symbol { get; set; }
        public string Name { get; set; }
    }
}