﻿using System;
using System.Collections.Generic;
using System.Windows;
using Infragistics.Controls.Charts;

namespace Infragistics.Extensions
{
    public class TriangulationData : AnnimationModel
    {
        public TriangulationData()
        {
            Timer.Interval = TimeSpan.FromMilliseconds(100);
            //DataSource = new SampleHeatData();
            DataSource = new ScatterData3D(500, 0);

            RefreshTriangulation();
        }
        
        //public ScatterPointList DataSource { get; set; }
        public ScatterData3D DataSource { get; set; }

        //public List<Point> TriangulationMeshPoints { get; set; }

        //public List<List<Point>> TriangulationMesh { get; set; }
        //public TriangulationSource TriangulationSource { get; set; }
        private List<Point> _triangulationMeshPoints;
        public List<Point> TriangulationMeshPoints
        {
            get { return _triangulationMeshPoints; }
            private set
            {
                _triangulationMeshPoints = value;
                OnPropertyChanged("TriangulationMeshPoints");
            }
        }
        private List<List<Point>> _triangulationMesh;
        public List<List<Point>> TriangulationMesh
        {
            get { return _triangulationMesh; }
            private set
            {
                _triangulationMesh = value;
                OnPropertyChanged("TriangulationMesh");
            }
        }
        private TriangulationSource _triangulationSource;
        public TriangulationSource TriangulationSource
        {
            get { return _triangulationSource; }
            private set
            {
                _triangulationSource = value;
                OnPropertyChanged("TriangulationSource");
            }
        }

        public override void RefreshData()
        {
            DataSeed += 0.01;
            DataSource.Update(DataSeed);

            RefreshTriangulation();
        }
        public void RefreshTriangulation()
        {
            // create Triangulation source
            var triangulationSource = TriangulationSource.Create(DataSource.Count,
            (i) => new Point(DataSource[i].X, DataSource[i].Y),
            (i) => Convert.ToSingle(DataSource[i].Z));

            // create Triangulation mesh
            var triangulationMesh = new List<List<Point>>();
            var triangulationMeshPoints = new List<Point>();

            var records = triangulationSource.Points;
            foreach (var triangle in triangulationSource.Triangles)
            {
                var trianglePoints = new List<Point>();
                //var index = triangle.V1;
                //var record = records[index];
                //trianglePoints.Add(record.Point);

                trianglePoints.Add(records[triangle.V1].Point);
                trianglePoints.Add(records[triangle.V2].Point);
                trianglePoints.Add(records[triangle.V3].Point);

                triangulationMeshPoints.Add(new Point(double.NaN, double.NaN));
                triangulationMeshPoints.Add(new Point(double.NaN, double.NaN));
                triangulationMeshPoints.AddRange(trianglePoints);
                triangulationMeshPoints.Add(new Point(double.NaN, double.NaN));
                triangulationMeshPoints.Add(new Point(double.NaN, double.NaN));

                triangulationMesh.Add(trianglePoints);
            }

            this.TriangulationSource = triangulationSource;
            this.TriangulationMesh = triangulationMesh;
            this.TriangulationMeshPoints = triangulationMeshPoints;
          
        }
    }


    public class SampleHeatData : ScatterPointList
    {
        public SampleHeatData()
        {
            var value = 0;
            this.Add(new ScatterPoint() { Value = value, X = 0, Y = 0 });
            this.Add(new ScatterPoint() { Value = value, X = 50, Y = 0 });
            this.Add(new ScatterPoint() { Value = value, X = 100, Y = 0 });
            this.Add(new ScatterPoint() { Value = value, X = 150, Y = 0 });
            this.Add(new ScatterPoint() { Value = value, X = 200, Y = 0 });
            value = 6;
            this.Add(new ScatterPoint() { Value = value, X = 0, Y = 30 });
            this.Add(new ScatterPoint() { Value = value, X = 25, Y = 30 });
            this.Add(new ScatterPoint() { Value = value, X = 75, Y = 30 });
            this.Add(new ScatterPoint() { Value = value, X = 125, Y = 25 });
            this.Add(new ScatterPoint() { Value = value, X = 175, Y = 25 });
            this.Add(new ScatterPoint() { Value = value, X = 200, Y = 25 });
            value = 6;
            this.Add(new ScatterPoint() { Value = value, X = 0, Y = 50 });
            this.Add(new ScatterPoint() { Value = value, X = 50, Y = 50 });
            this.Add(new ScatterPoint() { Value = value, X = 100, Y = 50 });
            this.Add(new ScatterPoint() { Value = value, X = 150, Y = 60 });
            this.Add(new ScatterPoint() { Value = value, X = 200, Y = 60 });
            value = 3;
            this.Add(new ScatterPoint() { Value = value, X = 0, Y = 80 });
            this.Add(new ScatterPoint() { Value = value, X = 25, Y = 80 });
            this.Add(new ScatterPoint() { Value = value, X = 75, Y = 80 });
            this.Add(new ScatterPoint() { Value = value, X = 125, Y = 70 });
            this.Add(new ScatterPoint() { Value = value, X = 175, Y = 70 });
            this.Add(new ScatterPoint() { Value = value, X = 200, Y = 70 });
            value = 3;
            this.Add(new ScatterPoint() { Value = value, X = 0, Y = 90 });
            this.Add(new ScatterPoint() { Value = value, X = 50, Y = 90 });
            this.Add(new ScatterPoint() { Value = value, X = 100, Y = 90 });
            this.Add(new ScatterPoint() { Value = value, X = 150, Y = 100 });
            this.Add(new ScatterPoint() { Value = value, X = 200, Y = 100 });

            value = 5;
            this.Add(new ScatterPoint() { Value = value, X = 0, Y = 120 });
            this.Add(new ScatterPoint() { Value = value, X = 25, Y = 120 });
            this.Add(new ScatterPoint() { Value = value, X = 75, Y = 120 });
            this.Add(new ScatterPoint() { Value = value, X = 125, Y = 125 });
            this.Add(new ScatterPoint() { Value = value, X = 175, Y = 125 });
            this.Add(new ScatterPoint() { Value = value, X = 200, Y = 125 });

            value = 5;
            this.Add(new ScatterPoint() { Value = value, X = 0, Y = 150 });
            this.Add(new ScatterPoint() { Value = value, X = 50, Y = 150 });
            this.Add(new ScatterPoint() { Value = value, X = 100, Y = 160 });
            this.Add(new ScatterPoint() { Value = value, X = 150, Y = 160 });
            this.Add(new ScatterPoint() { Value = value, X = 200, Y = 160 });

            value = 9;
            this.Add(new ScatterPoint() { Value = value, X = 0, Y = 170 });
            this.Add(new ScatterPoint() { Value = value, X = 25, Y = 170 });
            this.Add(new ScatterPoint() { Value = value, X = 75, Y = 170 });
            this.Add(new ScatterPoint() { Value = value, X = 125, Y = 170 });
            this.Add(new ScatterPoint() { Value = value, X = 175, Y = 180 });
            this.Add(new ScatterPoint() { Value = value, X = 200, Y = 180 });

            value = 9;
            this.Add(new ScatterPoint() { Value = value, X = 0, Y = 200 });
            this.Add(new ScatterPoint() { Value = value, X = 40, Y = 200 });
            this.Add(new ScatterPoint() { Value = value, X = 70, Y = 200 });
            this.Add(new ScatterPoint() { Value = value, X = 120, Y = 200 });
            this.Add(new ScatterPoint() { Value = value, X = 200, Y = 200 });


        }
    }

   
}