﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using Infragistics;
using Infragistics.Controls.Charts;

namespace SampleApp
{
    /// <summary>
    /// Interaction logic for StackedColumnAutoGenSeries.xaml
    /// </summary>
    public partial class StackedAutoGenSeries : UserControl
    {
        public StackedAutoGenSeries()
        {
            InitializeComponent();

            this.Loaded += StackedColumnAutoGenSeries_Loaded;
        }

        void StackedColumnAutoGenSeries_Loaded(object sender, RoutedEventArgs e)
        {
            TestData = GenerateTestData();
            var items = TestData.OrderBy(item => item.Date).ToList();

            GroupedData = new GroupBy();
            GroupedData.GroupMemberPath = "Date";
            GroupedData.KeyMemberPath = "Label";
            GroupedData.ValueMemberPath = "WorkHours";
            GroupedData.ItemsSource = items;

            CreateCategoryAxis();
            CreateDateTimeCategoryAxis();

        }
       
        private AxisLabelSettings GetXAxisLabelSetting()
        {
            var result = new AxisLabelSettings();
            result.Angle = 90;
            result.Extent = 60;
            result.Location = AxisLabelsLocation.OutsideBottom;
            return result;
        }
        private void CreateCategoryAxis()
        {
            //clear the chart
            Chart1.Series.Clear();
            Chart1.Axes.Clear();
 

            var yAxis = new NumericYAxis();
            yAxis.MinimumValue = 0;

            var xAxis = new CategoryXAxis();
            xAxis.ItemsSource = GroupedData;
            xAxis.Label = "{Key:yy-MM-dd}";
            xAxis.LabelSettings = GetXAxisLabelSetting();

            this.Chart1.Axes.Add(xAxis);
            this.Chart1.Axes.Add(yAxis);

            var series = new StackedAreaSeries();
            series.SeriesCreated += OnSeriesSegmentAutoCreated;
            series.XAxis = xAxis;
            series.YAxis = yAxis;
            series.ItemsSource = GroupedData;
            series.AutoGenerateSeries = true;
            Chart1.Series.Add(series);
        }

        private void CreateDateTimeCategoryAxis()
        {
            //clear the chart
            Chart2.Series.Clear();
            Chart2.Axes.Clear();
           
            var yAxis = new NumericYAxis();
            yAxis.MinimumValue = 0;

            var xAxis = new CategoryDateTimeXAxis();
            xAxis.ItemsSource = GroupedData;
            xAxis.DateTimeMemberPath = "Key";
            xAxis.Label = "{Key:yy-MM-dd}";
            xAxis.LabelSettings = GetXAxisLabelSetting();

            Chart2.Axes.Add(xAxis);
            Chart2.Axes.Add(yAxis);

            var series = new StackedAreaSeries();
            series.SeriesCreated += OnSeriesSegmentAutoCreated;
            series.XAxis = xAxis;
            series.YAxis = yAxis;
            series.ItemsSource = GroupedData;
            series.AutoGenerateSeries = true;
            Chart2.Series.Add(series);
        }
        protected IEnumerable<WorkingHourStacked> TestData;
        protected GroupBy GroupedData;
        protected List<string> GroupNames = new List<string>() { "Group1", "Group2", "Group3"};

        private IEnumerable<WorkingHourStacked> GenerateTestData()
        {
            //string group1 = "Group1";
            //string group2 = "Group2";
            //string group3 = "Group3";
            var resultList = new List<WorkingHourStacked>();

            DateTime testDate = DateTime.Now;
            resultList.Add(new WorkingHourStacked(GroupNames[0], testDate, 3));
            resultList.Add(new WorkingHourStacked(GroupNames[1], testDate, 0));
            resultList.Add(new WorkingHourStacked(GroupNames[2], testDate, 5));

            testDate = testDate.AddDays(2);
            resultList.Add(new WorkingHourStacked(GroupNames[0], testDate, 2));
            resultList.Add(new WorkingHourStacked(GroupNames[1], testDate, 7));
            resultList.Add(new WorkingHourStacked(GroupNames[2], testDate, 1));

            testDate = testDate.AddMonths(-1);
            resultList.Add(new WorkingHourStacked(GroupNames[0], testDate, 0));
            resultList.Add(new WorkingHourStacked(GroupNames[1], testDate, 3));
            resultList.Add(new WorkingHourStacked(GroupNames[2], testDate, 5));

            testDate = DateTime.Now.AddDays(10);
            resultList.Add(new WorkingHourStacked(GroupNames[0], testDate, 1));
            resultList.Add(new WorkingHourStacked(GroupNames[1], testDate, 5));
            resultList.Add(new WorkingHourStacked(GroupNames[2], testDate, 0));


            return resultList;
        }
        
        /// <summary>
        /// Access and change a subset of series properties from the event arguments.
        /// properties are exposed from the EventArgs so that developers cannot change 
        /// sensitive properties such as ItemSource, ValueMemberPath and X/YAxis at this
        /// point.  Setting these properties would override any properties set 
        /// on the Stacked Series
        /// </summary>
        private void OnSeriesSegmentAutoCreated(object sender, StackedSeriesCreatedEventArgs e)
        {
            var stackFragment = sender as StackedFragmentSeries;
           
            var i = e.Index;
            e.Title = GroupNames[i];

            // Optional properties to customize
            //e.Brush=[Brush];
            //e.DashArray=[Brush];
            //e.DashCap=[Brush];
            //e.EndCap=[Brush];
            //e.LegendItem={LegendItem];
            //e.LegendItemBadgeTemplate
            //e.LegendItemTemplate
            //e.LegendItemVisibility
            //e.LineJoin
            //e.MarkerBrush
            //e.MarkerOutline
            //e.MarkerStyle
            //e.MarkerTemplate
            //e.MarkerType
            //e.MiterLimit
            //e.Outline
            //e.StartCap
            //e.Thickness
            //e.Title
            //e.ToolTip
            //e.TransitionDuration

        }
       
    }

  
    public class WorkingHourStacked
    {
        public string Label { get; set; }
        public DateTime Date { get; set; }
        public double WorkHours { get; set; }

        public WorkingHourStacked(string name, DateTime date, double workHours)
        {
            Label = name;
            Date = date;
            WorkHours = workHours;
        }
    }
    
}
